==> gdata_2.8.0.zip: gdata/doc/unknown.R <==
###################################################
### chunk number 1: ex01
###################################################
library("gdata")
xNum <- c(0, 6, 0, 7, 8, 9, NA)
isUnknown(x=xNum)


###################################################
### chunk number 2: ex02
###################################################
isUnknown(x=xNum, unknown=0)


###################################################
### chunk number 3: ex03
###################################################
isUnknown(x=xNum, unknown=c(0, NA))


###################################################
### chunk number 4: ex04
###################################################
(xNum2 <- unknownToNA(x=xNum, unknown=0))


###################################################
### chunk number 5: ex05
###################################################
NAToUnknown(x=xNum2, unknown=999)


###################################################
### chunk number 6: ex06
###################################################
NAToUnknown(x=xNum2, unknown=7, force=TRUE)


###################################################
### chunk number 7: ex07
###################################################
(xFac <- factor(c(0, "BA", "RA", "BA", NA, "NA")))
isUnknown(x=xFac)
isUnknown(x=xFac, unknown=0)
isUnknown(x=xFac, unknown=c(0, NA))
isUnknown(x=xFac, unknown=c(0, "NA"))
isUnknown(x=xFac, unknown=c(0, "NA", NA))

(xFac <- unknownToNA(x=xFac, unknown=0))
(xFac <- NAToUnknown(x=xFac, unknown=0))


###################################################
### chunk number 8: ex08
###################################################
(xList <- list(a=xNum, b=xFac))
isUnknown(x=xList, unknown=0)


###################################################
### chunk number 9: ex09
###################################################
isUnknown(x=xList, unknown=c(0, NA))


###################################################
### chunk number 10: ex10
###################################################
(xList1 <- unknownToNA(x=xList,
                       unknown=list(b=c(0, "NA"),
                                    a=0)))


###################################################
### chunk number 11: ex11
###################################################
NAToUnknown(x=xList1,
            unknown=list(b="no", a=0))


###################################################
### chunk number 12: ex12
###################################################
df <- data.frame(col1=c(0, 1, 999, 2),
                 col2=c("a", "b", "c", "unknown"),
                 col3=c(0, 1, 2, 3),
                 col4=c(0, 1, 2, 2))


###################################################
### chunk number 13: ex13
###################################################
tmp <- list(.default=0,
            col1=999,
            col2="unknown")
(df2 <- unknownToNA(x=df,
                    unknown=tmp))


###################################################
### chunk number 14: ex14
###################################################
df2 <- df
cols <- c("col1", "col2")
tmp <- list(col1=999,
            col2="unknown")
df2[, cols] <- unknownToNA(x=df[, cols],
                           unknown=tmp)
df2

==> gdata_2.8.2.zip: gdata/doc/unknown.R <==
###################################################
### chunk number 1: ex01
###################################################
#line 61 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/unknown.Rnw"
library("gdata")
xNum <- c(0, 6, 0, 7, 8, 9, NA)
isUnknown(x=xNum)


###################################################
### chunk number 2: ex02
###################################################
#line 72 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/unknown.Rnw"
isUnknown(x=xNum, unknown=0)


###################################################
### chunk number 3: ex03
###################################################
#line 79 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/unknown.Rnw"
isUnknown(x=xNum, unknown=c(0, NA))


###################################################
### chunk number 4: ex04
###################################################
#line 89 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/unknown.Rnw"
(xNum2 <- unknownToNA(x=xNum, unknown=0))


###################################################
### chunk number 5: ex05
###################################################
#line 97 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/unknown.Rnw"
NAToUnknown(x=xNum2, unknown=999)


###################################################
### chunk number 6: ex06
###################################################
#line 105 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/unknown.Rnw"
NAToUnknown(x=xNum2, unknown=7, force=TRUE)


###################################################
### chunk number 7: ex07
###################################################
#line 118 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/unknown.Rnw"
(xFac <- factor(c(0, "BA", "RA", "BA", NA, "NA")))
isUnknown(x=xFac)
isUnknown(x=xFac, unknown=0)
isUnknown(x=xFac, unknown=c(0, NA))
isUnknown(x=xFac, unknown=c(0, "NA"))
isUnknown(x=xFac, unknown=c(0, "NA", NA))

(xFac <- unknownToNA(x=xFac, unknown=0))
(xFac <- NAToUnknown(x=xFac, unknown=0))


###################################################
### chunk number 8: ex08
###################################################
#line 159 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/unknown.Rnw"
(xList <- list(a=xNum, b=xFac))
isUnknown(x=xList, unknown=0)


###################################################
### chunk number 9: ex09
###################################################
#line 167 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/unknown.Rnw"
isUnknown(x=xList, unknown=c(0, NA))


###################################################
### chunk number 10: ex10
###################################################
#line 177 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/unknown.Rnw"
(xList1 <- unknownToNA(x=xList,
                       unknown=list(b=c(0, "NA"),
                                    a=0)))


###################################################
### chunk number 11: ex11
###################################################
#line 186 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/unknown.Rnw"
NAToUnknown(x=xList1,
            unknown=list(b="no", a=0))


###################################################
### chunk number 12: ex12
###################################################
#line 198 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/unknown.Rnw"
df <- data.frame(col1=c(0, 1, 999, 2),
                 col2=c("a", "b", "c", "unknown"),
                 col3=c(0, 1, 2, 3),
                 col4=c(0, 1, 2, 2))


###################################################
### chunk number 13: ex13
###################################################
#line 205 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/unknown.Rnw"
tmp <- list(.default=0,
            col1=999,
            col2="unknown")
(df2 <- unknownToNA(x=df,
                    unknown=tmp))


###################################################
### chunk number 14: ex14
###################################################
#line 217 "d:/Rcompile/CRANpkg/local/2.12/gdata/inst/doc/unknown.Rnw"
df2 <- df
cols <- c("col1", "col2")
tmp <- list(col1=999,
            col2="unknown")
df2[, cols] <- unknownToNA(x=df[, cols],
                           unknown=tmp)
df2
